// Copyright (C) 2009 Playedit.

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef METADATA_EDITOR_H
#define METADATA_EDITOR_H

#include "mtp_data_types.h"

#include <gtkmm/dialog.h>
#include <gtkmm/frame.h>
#include <gtkmm/grid.h>
#include <gtkmm/label.h>
#include <gtkmm/entry.h>
#include <gtkmm/spinbutton.h>

class BoldLabel : public Gtk::Label
{
	public:
		BoldLabel(const Glib::ustring &text, Gtk::Entry &mnemonic_widget);
};

class NumericSpinButton : public Gtk::SpinButton
{
	public:
		NumericSpinButton(int initial_value, int max_value);

	private:
		Glib::RefPtr<Gtk::Adjustment> m_Adjustment;
};

class AlbumMetadataEditor : public Gtk::Dialog
{
	public:
		AlbumMetadataEditor(const Glib::RefPtr<album_t>& album, const Glib::ustring& message = "");

	private:
		void on_response(int response_id);

		// Child widgets
		Gtk::Label m_MessageLabel;
		Gtk::Frame m_Frame;
		Gtk::Grid m_Grid;

		// Entries
		Gtk::Entry m_NameEntry, m_ArtistEntry, m_GenreEntry;
		BoldLabel m_NameLabel, m_ArtistLabel, m_GenreLabel;

		// Standard dialog buttons
		Gtk::Button m_ButtonCancel, m_ButtonOk;

		Glib::RefPtr<album_t> m_Album;
};

class TrackMetadataEditor : public Gtk::Dialog
{
	public:
		TrackMetadataEditor(const Glib::RefPtr<track_t>& track);

	private:
		void on_response(int response_id);

		// Child widgets
		Gtk::Grid m_Grid;

		// Entries
		Gtk::Entry m_NameEntry, m_AlbumEntry, m_ArtistEntry, m_GenreEntry;
		NumericSpinButton m_TrackDateSpin, m_TrackNumSpin,
			m_DurationMinSpin, m_DurationSecSpin, m_DurationMsSpin;
		BoldLabel m_NameLabel, m_AlbumLabel, m_ArtistLabel, m_GenreLabel, m_TrackDateLabel,
				  m_TrackNumLabel, m_DurationLabel;
		Gtk::Label m_DurationMinLabel, m_DurationSecLabel, m_DurationMsLabel;
		Gtk::Box m_DurationBox;

		// Standard dialog buttons
		Gtk::Button m_ButtonCancel, m_ButtonOk;

		Glib::RefPtr<track_t> m_Track;
};

#endif // METADATA_EDITOR_H
